@@ -32,7 +32,7 @@ class DataClient:
         self.token = os.environ["DC_TOKEN"] if "DC_TOKEN" in os.environ else token
 
         self.get_bars = partial(self.history, data_type="bar", freq="MS", use_cache=use_cache)
-        self.get_ticks = partial(self.history, data_type="tick", freq="12BH", use_cache=use_cache)
+        self.get_ticks = partial(self.history, data_type="tick", freq="12H", use_cache=use_cache)
         self.get_dailys = partial(self.history, data_type="daily", freq="AS", use_cache=use_cache)
 
     def status_check(self):
@@ -48,9 +48,9 @@ class DataClient:
                 print(e, "retrying...")
                 sleep(1)
 
-    def history(self, symbol, start_data, end_date, data_type, freq, use_cache):
-        date_split = pd.date_range(start_data, end_date, freq=freq)
-        date_split = [start_data, *date_split, end_date]
+    def history(self, symbol, start_date, end_date, data_type, freq, use_cache):
+        date_split = pd.date_range(start_date, end_date, freq=freq)
+        date_split = [start_date, *date_split, end_date]
         data = pd.DataFrame()
         self.status_check()
         for index, _ in enumerate(date_split):
@@ -88,14 +88,14 @@ if __name__ == "__main__":
     # 日线
     dailys = client.get_dailys(
         "CFFEX.IF@INDEX",
-        start_data=datetime(2018, 1, 1),
+        start_date=datetime(2018, 1, 1),
         end_date=datetime(2021, 6, 4)
     )
     print(dailys)
     # 分钟
     bars = client.get_bars(
         "SHFE.rb@INDEX",
-        start_data=datetime(2020, 4, 6),
+        start_date=datetime(2020, 4, 6),
         end_date=datetime(2021, 6, 4)
     )
     print(bars)
